@@ -271,9 +271,9 @@ class SwerveDrivetrain(Subsystem):
             )
         )
 
-        self.odometry.update(Rotation2d(self.gyro.get_robot_heading()), *module_states)
-        self.odometry_estimator.update(Rotation2d(self.gyro.get_robot_heading()), *module_states)
-        self.chassis_speeds = self.kinematics.toChassisSpeeds(module_states)
+        self.odometry.update(Rotation2d(self.gyro.get_robot_heading()), *self.swerve_positions)
+        self.odometry_estimator.update(Rotation2d(self.gyro.get_robot_heading()), *self.swerve_positions)
+        self.chassis_speeds = self.kinematics.toChassisSpeeds(*module_states)
 
     def stop(self):
         """
